@@ -4,24 +4,19 @@ Implementation of the database layer for PyPI Package serving and
 testresult storage.
 
 """
-import re
-import os, sys
-import py
 import json
-import xmlrpclib
-from devpi_server.types import propmapping
-from hashlib import md5
-from bs4 import BeautifulSoup
+import re
+import sys
+
 from pip.index import HTMLPage
 
+from .types import propmapping
 from .urlutil import DistURL, joinpath
 
 from logging import getLogger
 assert __name__ == "devpi_server.extpypi"
 log = getLogger(__name__)
 
-import json
-
 
 class IndexParser:
     ALLOWED_ARCHIVE_EXTS = ".egg .tar.gz .tar.bz2 .tar .tgz .zip".split()
@@ -51,7 +46,6 @@ class IndexParser:
         p = HTMLPage(html, disturl.url)
         seen = set()
         for link in p.links:
-            #newurl = disturl.joinpath(a.get("href"))
             newurl = DistURL(link.url)
             eggfragment = newurl.eggfragment
             if scrape and eggfragment:
@@ -292,10 +286,3 @@ class RefreshManager:
             for name in names:
                 self.extdb.getreleaselinks(name, refresh=True)
                 self.redis.srem(self.INVALIDSET, name)
-
-def parse_http_date_to_posix(date):
-    time = parse_date(date)
-    ### DST?
-    return (time - datetime.datetime(1970, 1, 1)).total_seconds()
-
-
